# Firebolt-ingest

[![Nightly code check](https://github.com/firebolt-db/firebolt-ingest/actions/workflows/nightly.yml/badge.svg)](https://github.com/firebolt-db/firebolt-ingest/actions/workflows/nightly.yml)
[![Unit tests](https://github.com/firebolt-db/firebolt-ingest/actions/workflows/unit-tests.yml/badge.svg)](https://github.com/firebolt-db/firebolt-ingest/actions/workflows/unit-tests.yml)
[![Code quality checks](https://github.com/firebolt-db/firebolt-ingest/actions/workflows/code-check.yml/badge.svg)](https://github.com/firebolt-db/firebolt-ingest/actions/workflows/code-check.yml)
![Coverage](https://img.shields.io/endpoint?url=https://gist.githubusercontent.com/yuryfirebolt/1f1682d25882f8f75003d29921feb0e4/raw/firebolt-ingest-coverage.json)

The Firebolt Ingest library provides auxiliary functionality for creation external and fact tables.
And ingest the data from one to another.

The library is based on firebolt-python-sdk.

### Prerequisites
* Python version 3.7 or later along with the pip package installer. For more information, see the [Python](https://www.python.org/downloads/) web page.
* Firebolt account, database and running engine.

### Installation
Use pip to install the Firebolt Ingest from the command line as shown in the example below:

```pip install firebolt-ingest```

### Examples
See jupyter notebook in the [examples](https://github.com/firebolt-db/firebolt-ingest/tree/main/examples) folder.

### License
The Firebolt Ingest is licensed under the [Apache License Version 2.0](https://github.com/firebolt-db/firebolt-ingest/blob/main/LICENSE) software license.
